@@ -5,7 +5,7 @@ from sqlalchemy.orm import relationship
 from sqlalchemy.sql.expression import false
 from sqlalchemy.sql.sqltypes import Boolean
 
-from . import Base
+from .base import Base
 
 if TYPE_CHECKING:  # pragma: no cover
     from .guild import Guild  # noqa
@@ -13,6 +13,8 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 class GuildAward(Base):
+    """Awards available on a guild."""
+
     __tablename__ = "guild_awards"
 
     id = Column(
@@ -71,6 +73,8 @@ class GuildAward(Base):
 
 
 class UserAward(Base):
+    """Awards that a user has achieved on a per guild basis."""
+
     __tablename__ = "user_awards"
 
     user_xid = Column(
