@@ -7,7 +7,7 @@ from sqlalchemy.sql.expression import false, text
 from sqlalchemy.sql.schema import ForeignKey
 from sqlalchemy.sql.sqltypes import Boolean, Integer
 
-from . import Base, now
+from .base import Base, now
 
 if TYPE_CHECKING:  # pragma: no cover
     from .game import Game  # noqa
@@ -15,6 +15,8 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 class Channel(Base):
+    """Represents a Discord text channel."""
+
     __tablename__ = "channels"
 
     xid = Column(
@@ -77,6 +79,10 @@ class Channel(Base):
         server_default=false(),
         doc="Unverified user posts will be deleted from this channel automatically.",
     )
+    motd = Column(
+        String(255),
+        doc="Channel message of the day",
+    )
 
     guild = relationship(
         "Guild",
@@ -101,4 +107,5 @@ class Channel(Base):
             "auto_verify": self.auto_verify,
             "unverified_only": self.unverified_only,
             "verified_only": self.verified_only,
+            "motd": self.motd,
         }
