@@ -1,9 +1,11 @@
 from sqlalchemy import BigInteger, Boolean, Column, false
 
-from . import Base
+from .base import Base
 
 
 class Verify(Base):
+    """Records of a user's verification status on a per guild basis."""
+
     __tablename__ = "verify"
 
     guild_xid = Column(
