@@ -2,7 +2,7 @@ from typing import TYPE_CHECKING
 
 from sqlalchemy import BigInteger, Column, ForeignKey, String
 
-from . import Base
+from .base import Base
 
 if TYPE_CHECKING:  # pragma: no cover
     from .guild import Guild  # noqa
@@ -10,6 +10,8 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 class Watch(Base):
+    """Records of watched users on a per guild basis."""
+
     __tablename__ = "watches"
 
     guild_xid = Column(
