@@ -5,7 +5,7 @@ import discord
 from discord.errors import DiscordException
 from discord_slash.context import ComponentContext, InteractionContext
 
-from spellbot.utils import (
+from .utils import (
     CANT_SEND_CODE,
     DiscordChannel,
     bot_can_delete_channel,
@@ -186,7 +186,7 @@ async def safe_ensure_voice_category(
         sorted(
             (c for c in guild.categories if c.name.startswith(prefix)),
             key=category_num,
-        )
+        ),
     ):
         cat_num = category_num(cat)
         if cat_num < 0:
